@@ -29,9 +29,7 @@ try:
     from collections.abc import Sequence
 except ImportError:
     from collections import Sequence
-from collections import defaultdict
 import datetime
-from fnmatch import fnmatch
 import logging
 import operator
 import os
@@ -246,32 +244,11 @@ class BaseCli(dnf.Base):
                         logger.info(_("A transient overlay will be created on /usr that will be discarded on reboot. "
                                       "Keep in mind that changes to /etc and /var will still persist, and packages "
                                       "commonly modify these directories."))
-                self._persistence = libdnf.transaction.TransactionPersistence_TRANSIENT
-
-                # Check whether the transaction modifies usr_drift_protected_paths
-                transaction_protected_paths = defaultdict(list)
-                for pkg in trans:
-                    for pkg_file_path in sorted(pkg.files):
-                        for protected_pattern in self.conf.usr_drift_protected_paths:
-                            if fnmatch(pkg_file_path, protected_pattern):
-                                transaction_protected_paths[pkg.nevra].append(pkg_file_path)
-                if transaction_protected_paths:
-                    logger.info(_('This operation would modify the following paths, possibly introducing '
-                                  'inconsistencies when the transient overlay on /usr is discarded. See the '
-                                  'usr_drift_protected_paths configuration option for more information.'))
-                    for nevra, protected_paths in transaction_protected_paths.items():
-                        logger.info(nevra)
-                        for protected_path in protected_paths:
-                            logger.info("  %s" % protected_path)
-                    raise CliError(_("Operation aborted. Pass --setopt=usr_drift_protected_paths= to disable this check and proceed anyway."))
-
             else:
                 # Not a bootc transaction.
                 if self.conf.persistence == "transient":
                     raise CliError(_("Transient transactions are only supported on bootc systems."))
 
-                self._persistence = libdnf.transaction.TransactionPersistence_PERSIST
-
             if self._promptWanted():
                 if self.conf.assumeno or not self.output.userconfirm():
                     raise CliError(_("Operation aborted."))
@@ -382,7 +359,7 @@ class BaseCli(dnf.Base):
     def format_changelog(self, changelog):
         """Return changelog formatted as in spec file"""
         chlog_str = '* %s %s\n%s\n' % (
-            changelog['timestamp'].strftime("%a %b %d %X %Y"),
+            changelog['timestamp'].strftime("%c"),
             dnf.i18n.ucd(changelog['author']),
             dnf.i18n.ucd(changelog['text']))
         return chlog_str
